==> openshift-model-4.13.3-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterOperatorListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterOperatorListFluent<A extends ClusterOperatorListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ClusterOperator item);
    public A setToItems(int index,ClusterOperator item);
    public A addToItems(ClusterOperator... items);
    public A addAllToItems(Collection<ClusterOperator> items);
    public A removeFromItems(ClusterOperator... items);
    public A removeAllFromItems(Collection<ClusterOperator> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ClusterOperatorBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ClusterOperator> getItems();
    public List<ClusterOperator> buildItems();
    public ClusterOperator buildItem(int index);
    public ClusterOperator buildFirstItem();
    public ClusterOperator buildLastItem();
    public ClusterOperator buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterOperatorBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterOperatorBuilder> predicate);
    public A withItems(List<ClusterOperator> items);
    public A withItems(ClusterOperator... items);
    public Boolean hasItems();
    public ClusterOperatorListFluent.ItemsNested<A> addNewItem();
    public ClusterOperatorListFluent.ItemsNested<A> addNewItemLike(ClusterOperator item);
    public ClusterOperatorListFluent.ItemsNested<A> setNewItemLike(int index,ClusterOperator item);
    public ClusterOperatorListFluent.ItemsNested<A> editItem(int index);
    public ClusterOperatorListFluent.ItemsNested<A> editFirstItem();
    public ClusterOperatorListFluent.ItemsNested<A> editLastItem();
    public ClusterOperatorListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterOperatorBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterOperatorFluent<ClusterOperatorListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}

==> openshift-model-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterOperatorListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterOperatorListFluent<A extends ClusterOperatorListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ClusterOperator item);
    public A setToItems(int index,ClusterOperator item);
    public A addToItems(ClusterOperator... items);
    public A addAllToItems(Collection<ClusterOperator> items);
    public A removeFromItems(ClusterOperator... items);
    public A removeAllFromItems(Collection<ClusterOperator> items);
    public A removeMatchingFromItems(Predicate<ClusterOperatorBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ClusterOperator> getItems();
    public List<ClusterOperator> buildItems();
    public ClusterOperator buildItem(int index);
    public ClusterOperator buildFirstItem();
    public ClusterOperator buildLastItem();
    public ClusterOperator buildMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
    public A withItems(List<ClusterOperator> items);
    public A withItems(ClusterOperator... items);
    public Boolean hasItems();
    public ClusterOperatorListFluent.ItemsNested<A> addNewItem();
    public ClusterOperatorListFluent.ItemsNested<A> addNewItemLike(ClusterOperator item);
    public ClusterOperatorListFluent.ItemsNested<A> setNewItemLike(int index,ClusterOperator item);
    public ClusterOperatorListFluent.ItemsNested<A> editItem(int index);
    public ClusterOperatorListFluent.ItemsNested<A> editFirstItem();
    public ClusterOperatorListFluent.ItemsNested<A> editLastItem();
    public ClusterOperatorListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterOperatorFluent<ClusterOperatorListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
